/*
 * Software License Agreement (BSD License)
 *
 * Copyright (c) 2018 Oliver Mayer, Akademie der Bildenden Kuenste Nuernberg. 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * - Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

/*****************************************************************************  
 * Sends the values of three photoresistors connected to an Arduino
 * to a local Wekinator (machine learning app) via OSC (open sound control).
 * Use a processing example from the Wekinator website as output app.
 *****************************************************************************/

import processing.serial.*;
import cc.arduino.*;

import oscP5.*;
import netP5.*;

Arduino arduino;

OscP5 oscP5;
NetAddress dest;

int analogValue0;
int analogValue1;
int analogValue2;

void setup()
{
  size(500, 500);
  
  // init OSC messaging
  oscP5 = new OscP5(this,9000);
  dest = new NetAddress("127.0.0.1",6448);
  
  //println(Arduino.list());
  arduino = new Arduino(this, Arduino.list()[0], 57600);
  
}

void draw()
{
  // read photoresistor values
  analogValue0 = arduino.analogRead(0);
  analogValue1 = arduino.analogRead(1);
  analogValue2 = arduino.analogRead(2);

  // set background according to photoresistor values
  background(analogValue0/4,analogValue1/4,analogValue2/4);
  
  // send photoresistor values to Wekinator
  sendOsc();
}


void sendOsc() {
  // init message
  OscMessage msg = new OscMessage("/wek/inputs");
  
  // add photoresistor values to message
  msg.add((float)analogValue0/1023.0);
  msg.add((float)analogValue1/1023.0);
  msg.add((float)analogValue2/1023.0);

  // send message
  oscP5.send(msg, dest);
}
